@@ -8,5 +8,13 @@ class IssueCreateError(Exception):
     pass
 
 
+class TagError(Exception):
+    pass
+
+
 class TagNotFound(Exception):
     pass
+
+
+class TagExistsError(Exception):
+    pass
